<?php

namespace Drupal\eca_push_framework\Plugin\ECA\Event;

use Drupal\eca\Plugin\ECA\Event\EventBase;
use Drupal\push_framework\ChannelEvents;
use Drupal\push_framework\Event\ChannelEventBase;
use Drupal\push_framework\Event\ChannelEventLanguageBase;
use Drupal\push_framework\Event\ChannelPostRender;
use Drupal\push_framework\Event\ChannelPreBuild;
use Drupal\push_framework\Event\ChannelPrepareTemplates;
use Drupal\push_framework\Event\ChannelPreRender;

/**
 * Plugin implementation of the ECA Events for the Push Framework.
 *
 * @EcaEvent(
 *   id = "push_framework_channel",
 *   deriver = "Drupal\eca_push_framework\Plugin\ECA\Event\ChannelEventDeriver"
 * )
 */
class ChannelEvent extends EventBase {

  /**
   * {@inheritdoc}
   */
  public static function definitions(): array {
    $events = [];
    $events['prepare_templates'] = [
      'label' => 'Prepare templates',
      'event_name' => ChannelEvents::PREPARE_TEMPLATES,
      'event_class' => ChannelPrepareTemplates::class,
    ];
    $events['pre_build'] = [
      'label' => 'Pre build notification',
      'event_name' => ChannelEvents::PRE_BUILD,
      'event_class' => ChannelPreBuild::class,
    ];
    $events['pre_render'] = [
      'label' => 'Pre render notification',
      'event_name' => ChannelEvents::PRE_RENDER,
      'event_class' => ChannelPreRender::class,
    ];
    $events['post_render'] = [
      'label' => 'Post render notification',
      'event_name' => ChannelEvents::POST_RENDER,
      'event_class' => ChannelPostRender::class,
    ];
    return $events;
  }

  /**
   * {@inheritdoc}
   */
  protected function buildEventData(): array {
    $event = $this->getEvent();
    $data = [];

    if ($event instanceof ChannelEventBase) {
      $data['push_notification'] = [
        'channel' => $event->getChannelPlugin()->getPluginId(),
        'recipient' => $event->getUser(),
        'entity' => $event->getEntity(),
        'display_mode' => $event->getDisplayMode(),
      ];
      if ($event instanceof ChannelPrepareTemplates) {
        $data['push_notification'] += [
          'subject' => $event->getSubject(),
          'body' => $event->getBody(),
          'text_format' => $event->getTextFormat(),
          'is_html' => $event->isHtml(),
        ];
      }
      if ($event instanceof ChannelEventLanguageBase) {
        $data['push_notification'] += [
          'language_key' => $event->getLanguageKey(),
        ];
      }
      if ($event instanceof ChannelPreRender) {
        $data['push_notification'] += [
          'elements' => $event->getElements(),
        ];
      }
      if ($event instanceof ChannelPostRender) {
        $data['push_notification'] += [
          'output' => $event->getOutput(),
        ];
      }
    }

    $data += parent::buildEventData();
    return $data;
  }

}
